PhViD.search(RESULT, DRUG = NULL, EVENT = NULL)RESULT must be the output of one the signal detection method functions (ROR, PRR, RFET, GPS or BCPNNDRUG=FALSE.EVENT=FALSE.dataframe that contains the labels, the counts, the expected counts, the value of the statistic of interest, the rank and the estimated FDR for each couple.